import * as React from 'react';
/**
 * Wrapper for React Context that does not allow undefined values
 *
 * @template T The type of value the context should hold
 */
export type SafeContext<T> = {
    /** Consumer component for the context */
    Consumer: React.ComponentType<React.ConsumerProps<T>>;
    /** Provider component for the context */
    Provider: React.ComponentType<React.ProviderProps<T>>;
    /** Custom hook to get the context's value */
    useValue: () => T;
};
/**
 * Creates an object that wraps a React Context and provides non-undefined values via the consumer and a custom hook. Also
 * prevents providing undefined as a value to the provider
 *
 * @template T The type of value the context should hold
 * @param {string} name The name of the context, used when no value is provided
 * @param {T} initialValue Optional initial value to store in the context
 * @returns {SafeContext<T>} The context wrapper, containing Consumer and Provider components, as well as a custom hook
 */
export declare const createSafeContext: <T>(name: string, initialValue?: T) => SafeContext<T>;
